@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Open.py,v 1.17 1999/09/24 07:21:10 gobry Exp $
+# $Id: Open.py,v 1.18 1999/09/28 07:32:20 gobry Exp $
 
 
 from types import *
@@ -75,9 +75,9 @@ def bibopen (entity, how = None):
 		base = None
 
 		if how == None:
-			method = Autoload.available ("format")
+			listedmethods = Autoload.available ("format")
 			
-			for method in ListedMethods:
+			for method in listedmethods:
 				opener = get_by_name (method, 'open')
 				if opener:
 					base = opener (url, 1)
