@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: TextUI.py,v 1.17 1999/08/06 12:49:11 gobry Exp $
+# $Id: TextUI.py,v 1.19 1999/09/30 15:21:04 gobry Exp $
 
 # --------------------------------------------------
 # Basical `high level' functions
@@ -27,7 +27,7 @@ from types import *
 
 import os, sys, traceback, tempfile, string
 
-from Pyblio import Base, Help, Search, Types
+from Pyblio import Base, Help, Search, Types, Autoload
 from Pyblio.Open import bibopen, bibwrite
 
 # ----- Create elementary Test -----
@@ -39,7 +39,10 @@ The general syntax of a search is :
 
 ...where `constraints' is an arbitrary construction of :
 
-  -  has (field, value) : match if `field' matches `value' (as a REGEXP)
+  -  has (field, value) : matches if `field' matches `value' (as a REGEXP)
+  -  has_key (key) : matches if the entry matches the key
+  -  has_type (typename) : matches if the entry is of the given type
+  
   -  &, | : boolean operators (& = and, | = or)
 
 Negation of a constraint is noted `- constraint'.
@@ -60,6 +63,15 @@ See also: search, references
 def has (field, value):
 	return Search.Tester (field, value)
 
+def has_key (value):
+	return Search.KeyTester (value)
+
+def has_type (value):
+	the_type = Types.getentry (value, 0)
+	if the_type is None:
+		raise TypeError, "no such entry type"
+	
+	return Search.TypeTester (the_type)
 
 Help.register ('search',"""
 Usage: search (database, request)
@@ -211,3 +223,40 @@ def ls (refs, inpager = 1):
 	except IOError:
 		print "warning: broken pipe"
 
+
+# ---------- Format ----------
+
+Help.register ('format', """
+Syntax : format (database, style, output_format, [filehandle], [id])
+
+This function formats a database according to the given style and
+output format. The formatted database is sent to stdout or
+[filehandle] if specified.
+
+See also: available ()
+""")
+
+
+available = Autoload.available
+
+Help.register ('available', """
+Syntax : list = available (category)
+
+This function returns the list of available modules in a given
+category.
+
+Example:
+	available ('style')
+	available ('output')
+	
+""")
+
+def format (database, style, output, file = sys.stdout, id = 'Bibliography'):
+	
+	style  = Autoload.get_by_name ("style",  style)
+	output = Autoload.get_by_name ("output", output)
+
+	formatter = output.data (file)
+	style.data (id, formatter, database)
+
+	return
