@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: accents.c,v 1.9 1999/08/31 13:08:46 gobry Exp $
+ $Id: accents.c,v 1.10 1999/09/24 07:15:42 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -105,6 +105,14 @@ CharMapping cedilla [] = {
     {0, 0}
 };
 
+CharMapping tilda [] = {
+    {'A', ''},
+    {'O', ''},
+    {'a', ''},
+    {'o', ''},
+    {0, 0}
+};
+
 StringMapping commands [] = {
     {"backslash", "\\"},
     {NULL, NULL}
@@ -183,6 +191,8 @@ bibtex_accent_string (BibtexStruct * s,
     static gchar * hat_table = NULL;
     static gchar * trema_table = NULL;
     static gchar * cedilla_table = NULL;
+    static gchar * tilda_table = NULL;
+
     static GHashTable * commands_table = NULL;
 
     gchar * text, * tmp, accent;
@@ -198,6 +208,7 @@ bibtex_accent_string (BibtexStruct * s,
 	hat_table      = initialize_table   (hat);
 	trema_table    = initialize_table   (trema);
 	cedilla_table  = initialize_table   (cedilla);
+	tilda_table    = initialize_table   (tilda);
 
 	commands_table = initialize_mapping (commands);
     }
@@ -215,6 +226,7 @@ bibtex_accent_string (BibtexStruct * s,
 	    accent == '^'  ||
 	    accent == '`'  ||
 	    accent == '"'  ||
+	    accent == '~'  ||
 	    accent == 'c') {
 	    
 	    text = eat_as_string (flow, 1, loss);
@@ -236,6 +248,9 @@ bibtex_accent_string (BibtexStruct * s,
 	    case 'c':
 		tmp = cedilla_table;
 		break;
+	    case '~':
+		tmp = tilda_table;
+		break;
 		
 	    default:
 		g_assert_not_reached ();
