@@ -42,7 +42,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibparse.y,v 1.28 1999/08/31 13:08:46 gobry Exp $
+ $Id: bibparse.y,v 1.30 1999/09/24 07:15:44 gobry Exp $
 */
 
 /*  #include "parsername.h" */
@@ -60,6 +60,7 @@ static BibtexEntry *	entry	= NULL;
 static int		start_line, entry_start;
 static BibtexSource *	current_source;
 static gchar *	        error_string = NULL;
+static gchar *	        warning_string = NULL;
 static GString *        tmp_string = NULL;
 
 static gboolean recovering = FALSE;
@@ -91,6 +92,7 @@ bibtex_analyzer_finish (BibtexSource * source)  {
 BibtexEntry * 
 bibtex_analyzer_parse (BibtexSource * source) {
   int ret;
+  gboolean is_comment;
 
   g_return_val_if_fail (source != NULL, NULL);
 
@@ -116,14 +118,21 @@ bibtex_analyzer_parse (BibtexSource * source) {
 
   bibtex_tmp_string_free ();
 
+  is_comment = (entry->type && (strcasecmp (entry->type, "comment") == 0));
+
+  if (warning_string && ! is_comment) {
+      bibtex_warning (warning_string);
+  }
+  
   if (ret != 0) {
       source->line += entry->length;
-      bibtex_entry_destroy (entry, TRUE);
-      entry = NULL;
-
-      if (error_string) {
+      
+      if (error_string && ! is_comment) {
 	  bibtex_error (error_string);
       }
+
+      bibtex_entry_destroy (entry, TRUE);
+      entry = NULL;
   }
 
   if (error_string) {
@@ -131,6 +140,11 @@ bibtex_analyzer_parse (BibtexSource * source) {
       error_string = NULL;
   }
 
+  if (warning_string) {
+      g_free (warning_string);
+      warning_string = NULL;
+  }
+
   return entry;
 }
 
@@ -154,12 +168,12 @@ bibtex_parser_error (char * s) {
 void 
 bibtex_parser_warning (char * s) {
     if (current_source) {
-	bibtex_warning ("%s:%d: %s", current_source->name,
-			start_line + entry->length, s);
+	warning_string = g_strdup_printf ("%s:%d: %s", current_source->name,
+					  start_line + entry->length, s);
     }
     else {
-	bibtex_warning ("%d: %s", 
-			start_line + entry->length, s);
+	warning_string = g_strdup_printf ("%d: %s", 
+					  start_line + entry->length, s);
 
     }
 }
@@ -183,18 +197,17 @@ bibtex_parser_start_error (char * s) {
 static void 
 bibtex_parser_start_warning (char * s) {
     if (current_source) {
-	bibtex_warning ("%s:%d: %s", current_source->name,
-			entry_start, s);
+	warning_string = g_strdup_printf ("%s:%d: %s", current_source->name,
+					  entry_start, s);
     }
     else {
-	bibtex_warning ("%d: %s", 
-			entry_start, s);
-
+	warning_string = g_strdup_printf ("%d: %s", 
+					  entry_start, s);
     }
 }
 
 
-#line 176 "bibparse.y"
+#line 189 "bibparse.y"
 typedef union{
     gchar * text;
     BibtexStruct * body;
@@ -275,10 +288,10 @@ static const short yyrhs[] = {    10,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   205,   214,   223,   230,   248,   266,   273,   287,   293,   299,
-   311,   359,   377,   383,   396,   397,   412,   413,   425,   432,
-   441,   447,   457,   464,   472,   478,   485,   496,   503,   512,
-   522,   529
+   218,   227,   236,   243,   261,   279,   286,   300,   306,   312,
+   324,   372,   390,   396,   409,   410,   425,   426,   438,   445,
+   454,   460,   470,   477,   485,   491,   498,   509,   516,   525,
+   535,   542
 };
 #endif
 
@@ -899,7 +912,7 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 207 "bibparse.y"
+#line 220 "bibparse.y"
 {
     entry->type = g_strdup (yyvsp[-3].text);
     g_strdown (entry->type);
@@ -908,7 +921,7 @@ case 1:
 ;
     break;}
 case 2:
-#line 216 "bibparse.y"
+#line 229 "bibparse.y"
 { 
     entry->type = g_strdup (yyvsp[-3].text);
     g_strdown (entry->type);
@@ -917,14 +930,14 @@ case 2:
 ;
     break;}
 case 3:
-#line 225 "bibparse.y"
+#line 238 "bibparse.y"
 { 
     current_source->eof = TRUE; 
     YYABORT; 
 ;
     break;}
 case 4:
-#line 232 "bibparse.y"
+#line 245 "bibparse.y"
 {
     if (current_source->strict) {
 	bibtex_parser_start_error ("perhaps a missing coma");
@@ -942,7 +955,7 @@ case 4:
 ;
     break;}
 case 5:
-#line 250 "bibparse.y"
+#line 263 "bibparse.y"
 {
     if (current_source->strict) {
 	bibtex_parser_start_error ("perhaps a missing coma");
@@ -960,39 +973,39 @@ case 5:
 ;
     break;}
 case 6:
-#line 268 "bibparse.y"
+#line 281 "bibparse.y"
 {
     bibtex_parser_start_error ("end of file during processing");
     YYABORT;
 ;
     break;}
 case 7:
-#line 275 "bibparse.y"
+#line 288 "bibparse.y"
 {
     bibtex_parser_start_error ("end of file during processing");
     YYABORT;
 ;
     break;}
 case 8:
-#line 289 "bibparse.y"
+#line 302 "bibparse.y"
 {
     nop ();
 ;
     break;}
 case 9:
-#line 295 "bibparse.y"
+#line 308 "bibparse.y"
 {
     nop ();
 ;
     break;}
 case 10:
-#line 301 "bibparse.y"
+#line 314 "bibparse.y"
 {
     nop ();
 ;
     break;}
 case 11:
-#line 313 "bibparse.y"
+#line 326 "bibparse.y"
 { 
     char * name;
     BibtexField * field;
@@ -1040,7 +1053,7 @@ case 11:
 ;
     break;}
 case 12:
-#line 361 "bibparse.y"
+#line 374 "bibparse.y"
 { 
     entry_start = start_line + entry->length;
 
@@ -1053,23 +1066,23 @@ case 12:
 ;
     break;}
 case 13:
-#line 379 "bibparse.y"
+#line 392 "bibparse.y"
 { 
     yyval.body = bibtex_struct_append (yyvsp[-2].body, yyvsp[0].body);
 ;
     break;}
 case 14:
-#line 385 "bibparse.y"
+#line 398 "bibparse.y"
 {
     yyval.body = yyvsp[0].body;
 ;
     break;}
 case 15:
-#line 396 "bibparse.y"
+#line 409 "bibparse.y"
 { bibtex_parser_is_content = TRUE; ;
     break;}
 case 16:
-#line 399 "bibparse.y"
+#line 412 "bibparse.y"
 { 
     bibtex_parser_is_content = FALSE; 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
@@ -1079,11 +1092,11 @@ case 16:
 ;
     break;}
 case 17:
-#line 412 "bibparse.y"
+#line 425 "bibparse.y"
 { bibtex_parser_is_content = TRUE; ;
     break;}
 case 18:
-#line 415 "bibparse.y"
+#line 428 "bibparse.y"
 { 
     bibtex_parser_is_content = FALSE; 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
@@ -1093,42 +1106,42 @@ case 18:
 ;
     break;}
 case 19:
-#line 427 "bibparse.y"
+#line 440 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup (yyvsp[0].text);
 ;
     break;}
 case 20:
-#line 434 "bibparse.y"
+#line 447 "bibparse.y"
 {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_REF);
     yyval.body->value.ref = g_strdup (yyvsp[0].text);
 
-    g_strdown (yyval.body->value.ref);
+    /* g_strdown ($$->value.ref); */
 ;
     break;}
 case 21:
-#line 443 "bibparse.y"
+#line 456 "bibparse.y"
 { 
     yyval.body = yyvsp[0].body;
 ;
     break;}
 case 22:
-#line 449 "bibparse.y"
+#line 462 "bibparse.y"
 { 
     yyval.body = yyvsp[0].body;
 ;
     break;}
 case 23:
-#line 459 "bibparse.y"
+#line 472 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_COMMAND);
     yyval.body->value.com = g_strdup (yyvsp[0].text + 1);
 ;
     break;}
 case 24:
-#line 466 "bibparse.y"
+#line 479 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SUB);
     yyval.body->value.sub->encloser = BIBTEX_ENCLOSER_BRACE;
@@ -1136,34 +1149,34 @@ case 24:
 ;
     break;}
 case 25:
-#line 474 "bibparse.y"
+#line 487 "bibparse.y"
 {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SPACE);
 ;
     break;}
 case 26:
-#line 480 "bibparse.y"
+#line 493 "bibparse.y"
 {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_SPACE);
     yyval.body->value.unbreakable = TRUE;
 ;
     break;}
 case 27:
-#line 487 "bibparse.y"
+#line 500 "bibparse.y"
 {
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup (yyvsp[0].text);
 ;
     break;}
 case 28:
-#line 498 "bibparse.y"
+#line 511 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("");
 ;
     break;}
 case 29:
-#line 505 "bibparse.y"
+#line 518 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("\"");
@@ -1172,20 +1185,20 @@ case 29:
 ;
     break;}
 case 30:
-#line 514 "bibparse.y"
+#line 527 "bibparse.y"
 { 
     yyval.body = bibtex_struct_append (yyvsp[-1].body, yyvsp[0].body);
 ;
     break;}
 case 31:
-#line 524 "bibparse.y"
+#line 537 "bibparse.y"
 { 
     yyval.body = bibtex_struct_new (BIBTEX_STRUCT_TEXT);
     yyval.body->value.text = g_strdup ("");
 ;
     break;}
 case 32:
-#line 531 "bibparse.y"
+#line 544 "bibparse.y"
 { 
     yyval.body = bibtex_struct_append (yyvsp[-1].body, yyvsp[0].body);
 ;
@@ -1412,6 +1425,6 @@ yyerrhandle:
     }
   return 1;
 }
-#line 538 "bibparse.y"
+#line 551 "bibparse.y"
      
 	
