@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: struct.c,v 1.13 1999/09/24 07:15:46 gobry Exp $
+ $Id: struct.c,v 1.15 1999/09/28 07:32:31 gobry Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -345,7 +345,7 @@ bibtex_real_string (BibtexStruct * s,
 	    text = g_strdup (s->value.ref);
 	}
 	else {
-	    if (dico && as_latex) {
+	    if (dico) {
 		tmp_s = (BibtexStruct *) 
 		    g_hash_table_lookup (dico, s->value.ref);
 		
