@@ -9,16 +9,28 @@ from Pyblio.TextUI import *
 
 import string, os
 
-# define autoloaded modules
+# define autoloaded formats
 
-Autoload.register ('BibTeX', ['', '', '.bib'],   'Pyblio.Format.BibTeX')
-Autoload.register ('RefDB',  ['', '', '.brf'],   'Pyblio.Format.RefDB')
-Autoload.register ('Ovid',   ['', '', '.ovid'],  'Pyblio.Format.Ovid')
-Autoload.register ('DocBook',['', '', '.sgml'],  'Pyblio.Format.docbook')
+Autoload.preregister ('format', 'BibTeX', 'Pyblio.Format.BibTeX',  'file:.*\.bib')
+Autoload.preregister ('format', 'RefDB',  'Pyblio.Format.RefDB',   'file:.*\.brf')
+Autoload.preregister ('format', 'Ovid',   'Pyblio.Format.Ovid',    'file:.*\.ovid')
+Autoload.preregister ('format', 'DocBook','Pyblio.Format.docbook', 'file:.*\.sgml')
 
 # these two are very close
-Autoload.register ('Refer',    ['', '', '.refer'], 'Pyblio.Format.Refer')
-Autoload.register ('EndNote',  ['', '', '.end'],   'Pyblio.Format.Refer')
+Autoload.preregister ('format', 'Refer',   'Pyblio.Format.Refer', 'file:.*\.refer')
+Autoload.preregister ('format', 'EndNote', 'Pyblio.Format.Refer', 'file:.*\.end')
+
+
+# define styles and outputs
+
+Autoload.preregister ('style', 'Alpha',  'Pyblio.Style.alpha')
+Autoload.preregister ('style', 'Abbrv',  'Pyblio.Style.alpha')
+Autoload.preregister ('style', 'Custom', 'Pyblio.Style.custom')
+
+Autoload.preregister ('output', 'Text',  'Pyblio.Output.text')
+Autoload.preregister ('output', 'Raw',   'Pyblio.Output.raw')
+Autoload.preregister ('output', 'HTML',  'Pyblio.Output.html')
+Autoload.preregister ('output', 'LaTeX', 'Pyblio.Output.LaTeX')
 
 
 # Parse the configuration directory
