@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybcompact.py,v 1.4 1999/09/24 07:35:58 gobry Exp $
+# $Id: pybcompact.py,v 1.5 1999/09/30 15:21:06 gobry Exp $
 
 import string, os, re, copy
 from Pyblio import Base
@@ -63,7 +63,7 @@ def list_entries (file):
         # we match a new citation
         match = citation_re.search (line)
         if match:
-            citations.append (string.lower (match.group (1)))
+            citations.append (match.group (1))
             continue
 
         # we have to enter an additional .aux file
@@ -82,7 +82,7 @@ entries = list_entries (latex)
 h = {}
 for e in entries:
     h [e] = 1
-entries = filter (lambda x, h = h: h.has_key (x), entries)
+entries = h.keys ()
 
 # is there something to do ?
 if len (entries) == 0:
